# Example Orchestrations

This directory contains many examples of how orchestrations can be used with
Directord.

The examples here serve to show how things could be done and to help foster
ideas on how you may want to direct your deployment.
